@@ -7,16 +7,15 @@ from fullGSapi.cli.utils import LoginTokens, course_id_option, assignment_id_opt
 @click.command()
 @course_id_option
 @assignment_id_option
-@click.option("--submission", "-s", "submission", default=".", help="This is the file/folder which you want to submit.", type=click.Path())
 @click.option("--method", "-m", "method", default="upload", help="The method you are using to submit.", type=click.Choice(["upload", "github", "bitbucket"]))
 @click.option("--path", "-p", "path", default=".", help="The file or path which you want to submit", type=click.Path())
 @click.option("--repository", "-r", "repository", default=None, help="The full repository path of your repo (must include both the username and repo name).", type=str)
 @click.option("--branch", "-b", "branch", default=None, help="The branch which you want to submit.", type=str)
 @click.option("--email", "-e", "email", default=None, help="This option allows an instructor to submit an assignment on behalf of some student via their email.", type=str)
 @click.option("--leaderboard", "-l", "leaderboard", default="", help="This is the leaderboard name which will show up on Gradescope.", type=str)
-@click.option("--programming/--pdf", help="This is to set if you are submitting a programming vs PDF assignment.", type=bool)
+@click.option("--programming/--pdf", default=True, help="This is to set if you are submitting a programming vs PDF assignment.", type=bool)
 @click.pass_context
-def submit(ctx, course: str, assignment: str, submission: str, method: str, path: str, repository: str, branch: str, email: str, leaderboard: str, programming: bool):
+def submit(ctx, course: str, assignment: str, method: str, path: str, repository: str, branch: str, email: str, leaderboard: str, programming: bool):
     """
     This allows you to submit a programming or pdf assignment. Instructors may submit on behalf of students.
     """
@@ -29,11 +28,11 @@ def submit(ctx, course: str, assignment: str, submission: str, method: str, path
         if programming:
             click.echo("Collecting files...")
             filenames = getListOfFiles(path)
-            files = {f[(len(str(pathlib.Path(path).parent)) if os.path.isfile(path) else len(path)) + 1:]:open(f, 'rb') for f in filenames}
-            click.echo("Uploading...")
+            files = {f[(len(str(pathlib.Path(path).parent)) if os.path.isfile(path) else len(path)) + 1:]:open(f, 'rb').read() for f in filenames}
+            click.echo("Uploading programming submission...")
             res = gs.upload_programming_submission(course, assignment, email, files_dict=files)
         else:
-            click.echo("Uploading...")
+            click.echo("Uploading pdf subission...")
             res = gs.upload_pdf_submission(course, assignment, email, path)
         if res.ok:
             click.echo("Success!")
